// Edgardo Molina
// File: ImagePanel.cpp

#include <QtGui>

#include "ImagePanel.h"

// Constructor
ImagePanel::ImagePanel (QWidget* parent, Qt::WFlags f)
  : QWidget(parent, f) {
	// Set visual parameters
	QPalette pal;
	pal.setColor(QPalette::Window, QColor(Qt::black));
	pal.setColor(QPalette::WindowText, QColor(Qt::white));
	setPalette(pal);
	setBackgroundRole(QPalette::Window);
	setAutoFillBackground(true);
	
	// Set widget size
	resize(sizeHint());

	// reset will initialize some values
	reset();
}

// Destructor
ImagePanel::~ImagePanel() {
	// Currently nothing to destruct
}

// Init/Reset paramas
void
ImagePanel::reset() {
  	// initialize to empty pixmap
  	_pix = QPixmap();

	// Paint immediately
  	repaint();
}

// Shows an image on this widget
void
ImagePanel::show(QImage *img) {
	// Convert QImage to QPixmap for display purposes
  	_pix = QPixmap::fromImage(*img);
  	
	repaint();
}

// Called everytime a paint is needed
void
ImagePanel::paintEvent(QPaintEvent *e) {
  QPainter painter(this);
  painter.setBackgroundMode(Qt::OpaqueMode);
  painter.setBackground(QBrush(Qt::black));
  painter.drawPixmap(0,0,_pix);
}
