// Edgardo Molina
// File: ops.cpp

#include <cmath>
using namespace std;

#include <QImage>
#include <QColor>


#include "ops.h"


/**
 * GetChannel:
 *
 *  Returns an intensity image of a single channel.
 */
QImage*
getChannel(QImage *img, Channel ch) {
    QImage *newimg = new QImage(img->width(), img->height(), QImage::Format_RGB32);

    for(int y=0; y < newimg->height(); y++) {
        for(int x=0; x < newimg->width(); x++) {
            
            int color;
            switch(ch) {
                case Red:
                    color = qRed(img->pixel(x,y));
                    break;
                case Green:
                    color = qGreen(img->pixel(x,y));
                    break;
                case Blue:
                    color = qBlue(img->pixel(x,y));
                    break;
                case Alpha:
                    color = qAlpha(img->pixel(x,y));
                    break;
            };
            
            newimg->setPixel(x, y, qRgb(color,color,color));
        }
    }
    
    return newimg;
}


/**
 * ToGrayscale:
 *
 *  Returns a simple intensity image from a color image.
 *  gray = (r+g+b)/3
 */
QImage*
toGrayscale(QImage *img) {
    // Fill in
}


/**
 * ToLuminance:
 *
 *  Returns a luminance (NTSC) intensity image from a color image.
 *  gray = (r*11 + g*16 + b*5) / 32
 */
QImage*
toLuminance(QImage *img) {
    // Fill in
}


/**
 * Diff:
 *
 *  Returns an image of the absolute difference of the 2 input images.
 */
QImage*
diff(QImage *img1, QImage *img2) {
    if(!(img1->width() == img2->width() && img1->height() == img2->height())) return NULL;
    
    QImage *newimg = new QImage(img1->width(), img1->height(), QImage::Format_RGB32);
    
    for(int y=0; y < newimg->height(); y++) {
        for(int x=0; x < newimg->width(); x++) {
            QRgb c1 = img1->pixel(x,y);
            QRgb c2 = img2->pixel(x,y);
                        
            newimg->setPixel(x, y, qRgb(abs(qRed(c1)  -qRed(c2)),
                                        abs(qGreen(c1)-qGreen(c2)),
                                        abs(qBlue(c1) -qBlue(c2))));
        }
    }
    
    return newimg;
}
